@@ -2,7 +2,6 @@
 
 import logging
 import sys
-import time
 import multiprocessing
 from threading import Event
 
@@ -14,52 +13,54 @@ from .constants import APP_NAME
 from .log_utils import configure_log, enable_sanitization, configure_log_file
 
 configure_log(sys.stdout)
-log = logging.getLogger('')
-logging.getLogger('requests').setLevel(logging.CRITICAL)
+log = logging.getLogger("")
+logging.getLogger("requests").setLevel(logging.CRITICAL)
 
 
-def main(desktop=False, cef=False):
-    conf_file = conffile.get(APP_NAME, 'conf.json')
-    settings.load(conf_file)
+def main():
+    conf_file = conffile.get(APP_NAME, "conf.json")
+    load_success = settings.load(conf_file)
     i18n.configure()
 
     if settings.sanitize_output:
         enable_sanitization()
 
     if settings.write_logs:
-        log_file = conffile.get(APP_NAME, 'log.txt')
+        log_file = conffile.get(APP_NAME, "log.txt")
         configure_log_file(log_file)
 
     if sys.platform.startswith("darwin"):
-        multiprocessing.set_start_method('forkserver')
+        multiprocessing.set_start_method("forkserver")
 
-    userInterface = None
+    user_interface = None
     mirror = None
     use_gui = False
-    use_webview = desktop or settings.enable_desktop
+    gui_ready = None
     get_webview = lambda: None
-    if use_webview:
-        from .webclient_view import WebviewClient
-        userInterface = WebviewClient(cef=cef)
-        get_webview = userInterface.get_webview
-    elif settings.enable_gui:
+    if settings.enable_gui:
         try:
-            from .gui_mgr import userInterface
+            from .gui_mgr import user_interface
+
             use_gui = True
             gui_ready = Event()
-            userInterface.gui_ready = gui_ready
+            user_interface.gui_ready = gui_ready
         except Exception:
-            log.warning("Cannot load GUI. Falling back to command line interface.", exc_info=True)
-    
-    if settings.display_mirroring and not use_webview:
+            log.warning(
+                "Cannot load GUI. Falling back to command line interface.",
+                exc_info=True,
+            )
+
+    if settings.display_mirroring:
         try:
             from .display_mirror import mirror
+
             get_webview = mirror.get_webview
         except ImportError:
+            mirror = None
             log.warning("Cannot load display mirror.", exc_info=True)
 
-    if not userInterface:
-        from .cli_mgr import userInterface
+    if not user_interface:
+        from .cli_mgr import user_interface
 
     from .player import playerManager
     from .action_thread import actionThread
@@ -72,23 +73,25 @@ def main(desktop=False, cef=False):
     actionThread.start()
     playerManager.action_trigger = actionThread.trigger
     playerManager.get_webview = get_webview
-    userInterface.open_player_menu = playerManager.menu.show_menu
+    user_interface.open_player_menu = playerManager.menu.show_menu
     eventHandler.mirror = mirror
-    userInterface.start()
-    userInterface.login_servers()
+    user_interface.start()
+    user_interface.login_servers()
+
+    if not load_success:
+        log.error("Your configuration file is not valid JSON! It has been ignored!")
+        log.info("Tip: Open the JSON file in VS Code to see what is wrong.")
 
     try:
-        if use_webview:
-            userInterface.run()
-        elif mirror:
-            userInterface.stop_callback = mirror.stop
+        if mirror:
+            user_interface.stop_callback = mirror.stop
             # If the webview runs before the systray icon, it fails.
             if use_gui:
                 gui_ready.wait()
             mirror.run()
         else:
             halt = Event()
-            userInterface.stop_callback = halt.set
+            user_interface.stop_callback = halt.set
             try:
                 halt.wait()
             except KeyboardInterrupt:
@@ -99,12 +102,8 @@ def main(desktop=False, cef=False):
         timelineManager.stop()
         actionThread.stop()
         clientManager.stop()
-        userInterface.stop()
+        user_interface.stop()
 
-def main_desktop(cef=False):
-    desktop = "--shim" not in sys.argv
-    main(desktop, cef)
 
 if __name__ == "__main__":
     main()
-
